MessageType enum
Defines the type of a Hub Message.
Values
- undefined → const MessageType
-
MessageType is not defined.
- invocation → const MessageType
-
Indicates the message is an Invocation message and implements the {@link @microsoft/signalr.InvocationMessage} interface.
- streamItem → const MessageType
-
Indicates the message is a StreamItem message and implements the {@link @microsoft/signalr.StreamItemMessage} interface.
- completion → const MessageType
-
Indicates the message is a Completion message and implements the {@link @microsoft/signalr.CompletionMessage} interface.
- streamInvocation → const MessageType
-
Indicates the message is a Stream Invocation message and implements the {@link @microsoft/signalr.StreamInvocationMessage} interface.
- cancelInvocation → const MessageType
-
Indicates the message is a Cancel Invocation message and implements the {@link @microsoft/signalr.CancelInvocationMessage} interface.
- ping → const MessageType
-
Indicates the message is a Ping message and implements the {@link @microsoft/signalr.PingMessage} interface.
- close → const MessageType
-
Indicates the message is a Close message and implements the {@link @microsoft/signalr.CloseMessage} interface.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MessageType> - A constant List of the values in this enum, in order of their declaration.